@@ -326,6 +326,11 @@ pub enum WindowEvent<'a> {
   CloseRequested,
 
   /// The window has been destroyed.
+  ///
+  /// ## Platform-specific
+  ///
+  /// - **Windows / Linux:** Only fired if the [`crate::window::Window`] is dropped.
+  /// - **macOS:** Fired if the [`crate::window::Window`] is dropped or the dock `Quit` item is clicked.
   Destroyed,
 
   /// A file has been dropped into the window.
@@ -462,6 +467,13 @@ pub enum WindowEvent<'a> {
   ///
   /// At the moment this is only supported on Windows.
   ThemeChanged(Theme),
+
+  /// The window decorations has been clicked.
+  ///
+  /// ## Platform-specific
+  ///
+  /// - **Linux / macOS / Android / iOS:** Unsupported
+  DecorationsClick,
 }
 
 impl Clone for WindowEvent<'static> {
@@ -551,6 +563,7 @@ impl Clone for WindowEvent<'static> {
       ScaleFactorChanged { .. } => {
         unreachable!("Static event can't be about scale factor changing")
       }
+      DecorationsClick => DecorationsClick,
     };
   }
 }
@@ -635,6 +648,7 @@ impl<'a> WindowEvent<'a> {
       Touch(touch) => Some(Touch(touch)),
       ThemeChanged(theme) => Some(ThemeChanged(theme)),
       ScaleFactorChanged { .. } => None,
+      DecorationsClick => Some(DecorationsClick),
     }
   }
 }
