@@ -52,6 +52,8 @@ use crate::{
   },
 };
 
+use super::keyboard::{KeyEventBuilder, KEY_EVENT_BUILDERS};
+
 struct HMenuWrapper(HMENU);
 unsafe impl Send for HMenuWrapper {}
 unsafe impl Sync for HMenuWrapper {}
@@ -913,6 +915,10 @@ unsafe fn init<T: 'static>(
     menu: None,
   };
 
+  KEY_EVENT_BUILDERS
+    .lock()
+    .insert(win.id(), KeyEventBuilder::default());
+
   win.set_skip_taskbar(pl_attribs.skip_taskbar);
 
   let dimensions = attributes
